tic
data = readtable('data_VAR_CHP.xlsx');
elf_vol = data.ELF_VOL;
elf_mean = data.ELF_MEAN;
inf_cpi = data.INF_CPI;
cpi6 = data.CPI6;
cpi_d1 = data.CPI_D1_T_4;
px_mich = data.PX_MICH;
disp75 = data.DISP75_25_MICH;
cpi5yr = data.CPI5YR;
cpi5yr_d1 = data.CPI5_D1;
cpi10yr = data.CPI10YR;
cpi10yr_d1 = data.CPI10_D1;
booti=100000;

Mdl1 = varm(5,4);
[Mdl1,~,~,E1] = estimate(Mdl1, [elf_vol elf_mean inf_cpi cpi6 cpi_d1]);
[~,Lo1_90,Up1_90] = irf(Mdl1,'NumObs',10,"E",E1,"NumPaths",booti,'Confidence',0.90);
[Resp1,Lo1_68,Up1_68] = irf(Mdl1,'NumObs',10,"E",E1,"NumPaths",booti,'Confidence',0.68);

Mdl2 = varm(5,4);
[Mdl2,~,~,E2] = estimate(Mdl2, [elf_vol elf_mean inf_cpi px_mich disp75]);
[~,Lo2_90,Up2_90] = irf(Mdl2,'NumObs',10,"E",E2,"NumPaths",booti,'Confidence',0.90);
[Resp2,Lo2_68,Up2_68] = irf(Mdl2,'NumObs',10,"E",E2,"NumPaths",booti,'Confidence',0.68);
toc

Mdl3 = varm(5,4);
[Mdl3,~,~,E3] = estimate(Mdl3, [elf_vol elf_mean inf_cpi cpi5yr cpi5yr_d1]);
[~,Lo3_90,Up3_90] = irf(Mdl3,'NumObs',10,"E",E3,"NumPaths",booti,'Confidence',0.90);
[Resp3,Lo3_68,Up3_68] = irf(Mdl3,'NumObs',10,"E",E3,"NumPaths",booti,'Confidence',0.68);

Mdl4 = varm(5,4);
[Mdl4,~,~,E4] = estimate(Mdl4, [elf_vol elf_mean inf_cpi cpi10yr cpi10yr_d1]);
[~,Lo4_90,Up4_90] = irf(Mdl4,'NumObs',10,"E",E4,"NumPaths",booti,'Confidence',0.90);
[Resp4,Lo4_68,Up4_68] = irf(Mdl4,'NumObs',10,"E",E4,"NumPaths",booti,'Confidence',0.68);

%% Figures

hor = 10;
hh = 1:1:hor;
h0 = zeros(1, hor);
n = 5;
namevar1 = {' $w_v$', ' $w_m$', ' $\pi_t$', ' SPF $\pi_t^{1yr,\,exp}$',  'SPF $\pi_t^{1yr,\,dis}$'};
namevar2 = {' $w_v$', ' $w_m$', ' $\pi_t$', ' UofM  $\pi_t^{1yr,\,exp}$', ' UofM $\pi_t^{1yr,\,dis}$'};
namevar3 = {' $w_v$', ' $w_m$', ' $\pi_t$', ' SPF $\pi_t^{5yr,\,exp}$',  'SPF $\pi_t^{5yr,\,dis}$'};
namevar4 = {' $w_v$', ' $w_m$', ' $\pi_t$', ' SPF $\pi_t^{10yr,\,exp}$',  'SPF $\pi_t^{10yr,\,dis}$'};

lightblue = [0.3010 0.7450 0.9330];
deepblue = [0,0.4470,0.7410];
anotherblue = [0 0.5 1];
grey = [0.7 0.7 0.7];
darkred = [0.83,0.14,0.14];
yellowmustard = [1.00,0.54,0.00];
purple = [0.5 0 1];
green = [0.25,0.80,0.54];

figure('Renderer', 'painters', 'Position', [10 10 1800 600])

for i=1:n
subplot(2,n,i)
patch([hh fliplr(hh)], ...
      [Lo1_90(:,1,i)' fliplr(Up1_90(:,1,i)')], ...
      lightblue, 'FaceAlpha', 0.3, 'EdgeColor', 'none')
hold on
patch([hh fliplr(hh)], ... 
      [Lo1_68(:,1,i)' fliplr(Up1_68(:,1,i)')], ...
      deepblue, 'FaceAlpha', 0.3, 'EdgeColor',' none')
hold on
p = plot(hh, Resp1(:,1,i), 'k', ... 
         hh, h0, '--', 'lineWidth', 1);
xlim([1 hor])
p(1).LineWidth = 2;
title(strcat(namevar1{i}), 'interpreter', 'latex', 'fontsize', 13);
if i == 1
    ylabel('$w_v$ shock', 'interpreter', 'latex', 'fontsize', 13)
%    legend('Pct 90', 'Pct 68', 'IRF', 'Location', 'northeast');
end

subplot(2,n,n+i)
patch([hh fliplr(hh)], ...
      [Lo1_90(:,2,i)' fliplr(Up1_90(:,2,i)')], ...
      lightblue, 'FaceAlpha', 0.3, 'EdgeColor', 'none')
hold on
patch([hh fliplr(hh)], ... 
      [Lo1_68(:,2,i)' fliplr(Up1_68(:,2,i)')], ...
      deepblue, 'FaceAlpha', 0.3, 'EdgeColor',' none')
hold on
p = plot(hh, Resp1(:,2,i), 'k', ... 
         hh, h0, '--', 'lineWidth', 1);
xlim([1 hor])
p(1).LineWidth = 2;
title(strcat(namevar1{i}), 'interpreter', 'latex', 'fontsize', 13);
if i == 1
    ylabel('$w_m$ shock', 'interpreter', 'latex', 'fontsize', 13)
end
end

set(gcf, 'PaperUnits', 'centimeters');
set(gcf, 'PaperPosition', [0 0 50 15]);
saveas(gcf, strcat('IRF_SPF.png'))



figure('Renderer', 'painters', 'Position', [10 10 1800 600])

for i=1:n
subplot(2,n,i)
patch([hh fliplr(hh)], ...
      [Lo2_90(:,1,i)' fliplr(Up2_90(:,1,i)')], ...
      lightblue, 'FaceAlpha', 0.3, 'EdgeColor', 'none')
hold on
patch([hh fliplr(hh)], ... 
      [Lo2_68(:,1,i)' fliplr(Up2_68(:,1,i)')], ...
      deepblue, 'FaceAlpha', 0.3, 'EdgeColor',' none')
hold on
p = plot(hh, Resp2(:,1,i), 'k', ... 
         hh, h0, '--', 'lineWidth', 1);
xlim([1 hor])
p(1).LineWidth = 2;
title(strcat(namevar2{i}), 'interpreter', 'latex', 'fontsize', 13);
if i == 1
    ylabel('$w_v$ shock', 'interpreter', 'latex', 'fontsize', 13)
 %   legend('Pct 90', 'Pct 68', 'IRF', 'Location', 'northeast');
end

subplot(2,n,n+i)
patch([hh fliplr(hh)], ...
      [Lo2_90(:,2,i)' fliplr(Up2_90(:,2,i)')], ...
      lightblue, 'FaceAlpha', 0.3, 'EdgeColor', 'none')
hold on
patch([hh fliplr(hh)], ... 
      [Lo2_68(:,2,i)' fliplr(Up2_68(:,2,i)')], ...
      deepblue, 'FaceAlpha', 0.3, 'EdgeColor',' none')
hold on
p = plot(hh, Resp2(:,2,i), 'k', ... 
         hh, h0, '--', 'lineWidth', 1);
xlim([1 hor])
p(1).LineWidth = 2;
title(strcat(namevar2{i}), 'interpreter', 'latex', 'fontsize', 13);
if i == 1
    ylabel('$w_m$ shock', 'interpreter', 'latex', 'fontsize', 13)
end
end

% hL = legend('IRF', 'Pct 68', '', 'Pct 90');
% Programatically move the Legend
% newPosition = [0.925 0.85 0.05 0.08];
% newUnits = 'normalized';
% set(hL, 'Position', newPosition, 'Units', newUnits);

set(gcf, 'PaperUnits', 'centimeters');
set(gcf, 'PaperPosition', [0 0 50 15]);
saveas(gcf, strcat('IRF_UOM.png'))



figure('Renderer', 'painters', 'Position', [10 10 1800 600])

for i=1:n
subplot(2,n,i)
patch([hh fliplr(hh)], ...
      [Lo3_90(:,1,i)' fliplr(Up3_90(:,1,i)')], ...
      lightblue, 'FaceAlpha', 0.3, 'EdgeColor', 'none')
hold on
patch([hh fliplr(hh)], ... 
      [Lo3_68(:,1,i)' fliplr(Up3_68(:,1,i)')], ...
      deepblue, 'FaceAlpha', 0.3, 'EdgeColor',' none')
hold on
p = plot(hh, Resp3(:,1,i), 'k', ... 
         hh, h0, '--', 'lineWidth', 1);
xlim([1 hor])
p(1).LineWidth = 2;
title(strcat(namevar3{i}), 'interpreter', 'latex', 'fontsize', 13);
if i == 1
    ylabel('$w_v$ shock', 'interpreter', 'latex', 'fontsize', 13)
  %  legend('Pct 90', 'Pct 68', 'IRF', 'Location', 'northeast');
end

subplot(2,n,n+i)
patch([hh fliplr(hh)], ...
      [Lo3_90(:,2,i)' fliplr(Up3_90(:,2,i)')], ...
      lightblue, 'FaceAlpha', 0.3, 'EdgeColor', 'none')
hold on
patch([hh fliplr(hh)], ... 
      [Lo3_68(:,2,i)' fliplr(Up3_68(:,2,i)')], ...
      deepblue, 'FaceAlpha', 0.3, 'EdgeColor',' none')
hold on
p = plot(hh, Resp3(:,2,i), 'k', ... 
         hh, h0, '--', 'lineWidth', 1);
xlim([1 hor])
p(1).LineWidth = 2;
title(strcat(namevar3{i}), 'interpreter', 'latex', 'fontsize', 13);
if i == 1
    ylabel('$w_m$ shock', 'interpreter', 'latex', 'fontsize', 13)
end
end

set(gcf, 'PaperUnits', 'centimeters');
set(gcf, 'PaperPosition', [0 0 50 15]);
saveas(gcf, strcat('IRF_SPF_5Y.png'))

figure('Renderer', 'painters', 'Position', [10 10 1800 600])

for i=1:n
subplot(2,n,i)
patch([hh fliplr(hh)], ...
      [Lo4_90(:,1,i)' fliplr(Up4_90(:,1,i)')], ...
      lightblue, 'FaceAlpha', 0.3, 'EdgeColor', 'none')
hold on
patch([hh fliplr(hh)], ... 
      [Lo4_68(:,1,i)' fliplr(Up4_68(:,1,i)')], ...
      deepblue, 'FaceAlpha', 0.3, 'EdgeColor',' none')
hold on
p = plot(hh, Resp4(:,1,i), 'k', ... 
         hh, h0, '--', 'lineWidth', 1);
xlim([1 hor])
p(1).LineWidth = 2;
title(strcat(namevar4{i}), 'interpreter', 'latex', 'fontsize', 13);
if i == 1
    ylabel('$w_v$ shock', 'interpreter', 'latex', 'fontsize', 13)
   % legend('Pct 90', 'Pct 68', 'IRF', 'Location', 'northeast');
end

subplot(2,n,n+i)
patch([hh fliplr(hh)], ...
      [Lo4_90(:,2,i)' fliplr(Up4_90(:,2,i)')], ...
      lightblue, 'FaceAlpha', 0.3, 'EdgeColor', 'none')
hold on
patch([hh fliplr(hh)], ... 
      [Lo4_68(:,2,i)' fliplr(Up4_68(:,2,i)')], ...
      deepblue, 'FaceAlpha', 0.3, 'EdgeColor',' none')
hold on
p = plot(hh, Resp4(:,2,i), 'k', ... 
         hh, h0, '--', 'lineWidth', 1);
xlim([1 hor])
p(1).LineWidth = 2;
title(strcat(namevar4{i}), 'interpreter', 'latex', 'fontsize', 13);
if i == 1
    ylabel('$w_m$ shock', 'interpreter', 'latex', 'fontsize', 13)
end
end

set(gcf, 'PaperUnits', 'centimeters');
set(gcf, 'PaperPosition', [0 0 50 15]);
saveas(gcf, strcat('IRF_SPF_10Y.png'))

%% Combined 5 and 10 year



figure('Renderer', 'painters', 'Position', [10 10 1800 600])

for i=1:2
subplot(4,2, i)
patch([hh fliplr(hh)], ...
      [Lo3_90(:,1,i+3)' fliplr(Up3_90(:,1,i+3)')], ...
      lightblue, 'FaceAlpha', 0.3, 'EdgeColor', 'none')
hold on
patch([hh fliplr(hh)], ... 
      [Lo3_68(:,1,i+3)' fliplr(Up3_68(:,1,i+3)')], ...
      deepblue, 'FaceAlpha', 0.3, 'EdgeColor',' none')
hold on
p = plot(hh, Resp3(:,1,i+3), 'k', ... 
         hh, h0, '--', 'lineWidth', 1);
xlim([1 hor])
p(1).LineWidth = 2;
title(strcat(namevar3{i+3}), 'interpreter', 'latex', 'fontsize', 13);
if i == 1
    ylabel('$w_v$ shock', 'interpreter', 'latex', 'fontsize', 13)
    legend('Pct 90', 'Pct 68', 'IRF', 'Location', 'northeast');
end

subplot(4,2,2+i)
patch([hh fliplr(hh)], ...
      [Lo3_90(:,2,i+3)' fliplr(Up3_90(:,2,i+3)')], ...
      lightblue, 'FaceAlpha', 0.3, 'EdgeColor', 'none')
hold on
patch([hh fliplr(hh)], ... 
      [Lo3_68(:,2,i+3)' fliplr(Up3_68(:,2,i+3)')], ...
      deepblue, 'FaceAlpha', 0.3, 'EdgeColor',' none')
hold on
p = plot(hh, Resp3(:,2,i+3), 'k', ... 
         hh, h0, '--', 'lineWidth', 1);
xlim([1 hor])
p(1).LineWidth = 2;
title(strcat(namevar3{i+3}), 'interpreter', 'latex', 'fontsize', 13);
if i == 1
    ylabel('$w_m$ shock', 'interpreter', 'latex', 'fontsize', 13)
end
end

for i=1:2

subplot(4,2, 4+i)
patch([hh fliplr(hh)], ...
      [Lo4_90(:,1,i+3)' fliplr(Up4_90(:,1,i+3)')], ...
      lightblue, 'FaceAlpha', 0.3, 'EdgeColor', 'none')
hold on
patch([hh fliplr(hh)], ... 
      [Lo4_68(:,1,i+3)' fliplr(Up4_68(:,1,i+3)')], ...
      deepblue, 'FaceAlpha', 0.3, 'EdgeColor',' none')
hold on
p = plot(hh, Resp4(:,1,i+3), 'k', ... 
         hh, h0, '--', 'lineWidth', 1);
xlim([1 hor])
p(1).LineWidth = 2;
title(strcat(namevar4{i+3}), 'interpreter', 'latex', 'fontsize', 13);
if i == 1
    ylabel('$w_v$ shock', 'interpreter', 'latex', 'fontsize', 13)
    legend('Pct 90', 'Pct 68', 'IRF', 'Location', 'northeast');
end

subplot(4,2,i+6)
patch([hh fliplr(hh)], ...
      [Lo4_90(:,2,i+3)' fliplr(Up4_90(:,2,i+3)')], ...
      lightblue, 'FaceAlpha', 0.3, 'EdgeColor', 'none')
hold on
patch([hh fliplr(hh)], ... 
      [Lo4_68(:,2,i+3)' fliplr(Up4_68(:,2,i+3)')], ...
      deepblue, 'FaceAlpha', 0.3, 'EdgeColor',' none')
hold on
p = plot(hh, Resp4(:,2,i+3), 'k', ... 
         hh, h0, '--', 'lineWidth', 1);
xlim([1 hor])
p(1).LineWidth = 2;
title(strcat(namevar4{i+3}), 'interpreter', 'latex', 'fontsize', 13);
if i == 1
    ylabel('$w_m$ shock', 'interpreter', 'latex', 'fontsize', 13)
end

end

set(gcf, 'PaperUnits', 'centimeters');
set(gcf, 'PaperPosition', [0 0 50 15]);
saveas(gcf, strcat('IRF_SPF_5Y10Y.png'))

